#
# spec file for package python-pytest-html
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-html
Version:        4.1.1
Release:        4.1
Summary:        Pytest plugin for generating HTML reports
License:        MPL-2.0
URL:            https://github.com/pytest-dev/pytest-html
Source:         https://files.pythonhosted.org/packages/source/p/pytest-html/pytest_html-%{version}.tar.gz
# npm install --package-lock-only --legacy-peer-deps --ignore-scripts
Source10:       package-lock.json
Source11:       node_modules.spec.inc
%include        %{_sourcedir}/node_modules.spec.inc
# PATCH-FIX-OPENSUSE drop-assertpy-dep.patch
Patch1:         drop-assertpy-dep.patch
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  local-npm-registry
BuildRequires:  npm
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2 >= 3.0.0
Requires:       python-pytest >= 7.0.0
Requires:       python-pytest-metadata >= 3.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2 >= 3.0.0}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module pytest >= 7.0.0}
BuildRequires:  %{python_module pytest-metadata >= 3.0.0}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest-xdist}
# /SECTION
%python_subpackages

%description
A plugin for pytest that generates a HTML report for test results.

%prep
%autosetup -p1 -n pytest_html-%{version}
rm package-lock.json
local-npm-registry %{_sourcedir} install --also=dev
sed -i '/npm ci/d' scripts/npm.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest --ignore testing/test_integration.py --ignore testing/test_e2e.py

%files %{python_files}
%license LICENSE
%doc docs/changelog.rst README.rst
%{python_sitelib}/pytest_html
%{python_sitelib}/pytest_html-%{version}*-info

%changelog
* Thu Dec  5 2024 Nico Krapp <nico.krapp@suse.com>
- refresh node modules
  * update cross-spawn module to 7.0.6 - CVE-2024-21538 (bsc#1233852)
* Mon Oct 28 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update packages-lock.json to fix CVE-2024-48948, update elliptic js
  dependency to 6.6.0. bsc#1231688
* Mon Oct 14 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update packages-lock.json to fix CVE-2024-48949, update elliptic js
  dependency. bsc#1231562
* Fri May 17 2024 Daniel Garcia <daniel.garcia@suse.com>
- Replace node_modules.tar.gz vendoring with obs-service-node_modules
- Delete not needed patch vendor-npm.patch
- Update to 4.1.1:
  * fix: Latest eslint is broken (#769) @BeyondEvil
  * fix: original sort order (#768) @BeyondEvil
  * [pre-commit.ci] pre-commit autoupdate (#763) @pre-commit-ci
- 4.1.0:
  * Release v4.1.0 (#761) @BeyondEvil
  * fix: Escaping HTML in log (#757) @BeyondEvil
  * test: Add UTF8 test (#760) @BeyondEvil
  * [pre-commit.ci] pre-commit autoupdate (#563) @pre-commit-ci
  * fix: Only run npm when building from source (#758) @BeyondEvil
  * Fix results table modification documentation (#749) @michalkaptur
  * fix: Add collections errors to report (#756) @BeyondEvil
  * fix: Revert report generation to full run (#754) @BeyondEvil
  * fix: Broken duration (#753) @BeyondEvil
  * Pytest html fix reload button typo (#738) @jeffwright13
- 4.0.2:
  * Fix: Use absolute path for the report (#735) @adrien-berchet
- 4.0.1:
  * fix: Incorrect label for xfailed (#733) @BeyondEvil
* Mon Sep  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Refresh patches and node_modules.tar.gz
- Update to 4.0.0:
  * Feat: Add duration format hook (#724) @BeyondEvil
  * Chore: Drop support for python 3.7 (#723) @BeyondEvil
  * Add expander to log output (#721) @drRedflint
  * Fix: Broken sorting for custom columns (#715) @BeyondEvil
  * Chore: Stop running scheduled tests on forks (#720) @BeyondEvil
  * Chore: Fix tox (#718) @BeyondEvil
  * use max height instead of fixed height (#706) @drRedflint
  * if only one item in gallery, remove navigation (#705) @drRedflint
  * Chore: Support legacy pytest-metadata (#714) @BeyondEvil
  * Feature: Untemplate table header (#713) @BeyondEvil
  * Fix: Borken HTML in jinja template (#712) @BeyondEvil
  * Feature: Update json-data-blob (#704) @BeyondEvil
  * Fix: Collapsed state between redraws (#703) @BeyondEvil
  * Feature: Only one collapsed state (#701) @BeyondEvil
  * Chore: General JS cleanup (#700) @BeyondEvil
  * Feature: Template test and duration summary (#698) @BeyondEvil
  * Feature: Template result filters (#697) @BeyondEvil
  * Feature: Template table header (#696) @BeyondEvil
  * Fix: visible query param (#695) @BeyondEvil
  * Fix: Handle legacy py html (#694) @BeyondEvil
  * Fix: Environment table toggle bug (#693) @BeyondEvil
  * Feature: Add initial sort column as ini (#692) @BeyondEvil
  * Fix: Duration sorting (#691) @BeyondEvil
  * Fix: Logging issues with teardown (#690) @BeyondEvil
  * Chore: Simplify results table hooks (#688) @BeyondEvil
  * Enable variable expansion for CSS addons. (#676) @BeyondEvil
  * Fix: results table html hook (#669) @BeyondEvil
  * fix for #671 - Sort icons inverted in next-gen branch (#672) @harmin-parra
  * Docs: Update ReadTheDocs to v2 (#673) @BeyondEvil
  * Feature: Add 'session' to results summary hook (#660) @BeyondEvil
  * Chore: Fix npm building (#658) @BeyondEvil
  * Feature: Add hide-able Environment Table (#638) @BeyondEvil
  * Feature: Make entire row collapsible (#656) @BeyondEvil
  * Chore: Disambiguate collapsed (#657) @BeyondEvil
  * Chore: Assorted fixes around pytest entry points (#655) @BeyondEvil
  * Chore: Add eslint (#651) @BeyondEvil
  * Chore: Decouple ReportData (#650) @BeyondEvil
  * Chore: Add npm build hooks (#649) @BeyondEvil
  * Docs: Fix deprecations page title [skip ci] (#645) @BeyondEvil
  * Fix: Renamed report-data class to avoid confusion (#642) @BeyondEvil
  * Chore: Temporary imports for backwards compat (#643) @BeyondEvil
  * Docs: Add Deprecations docs (#640) @BeyondEvil
  * Fix: Support cells.pop() (#641) @BeyondEvil
  * Fix: Order and layout of outcome summary (#629) @BeyondEvil
  * Fix: Sorting of custom table columns (#634) @BeyondEvil
  * Chore: Allow concurrency on default branch (#639) @BeyondEvil
  * Fix: Initial sort and query param (#637) @BeyondEvil
  * Fix: Add skip marker results to report (#636) @BeyondEvil
  * Fix: Deprecate use of 'True' in render_collapsed (#635) @BeyondEvil
  * Fix: Color E(xecption) lines in the log red (#631) @BeyondEvil
  * Fix: Handle appends on table hooks (#630) @BeyondEvil
  * Fix: Handle assignment on table hooks (#628) @BeyondEvil
  * Docs: Update contrib docs (#627) @BeyondEvil
  * Fix issue with report.extra attribute (#626) @BeyondEvil
  * chore: It's , 120 is fine (#625) @BeyondEvil
  * Next gen (#621) @BeyondEvil
  * chore: Migrate from Poetry to Hatch (#617) @BeyondEvil
  * docs: Update to current (#616) @BeyondEvil
  * fix: Broken sorting due to typo in jinja template (#614) @BeyondEvil
  * fix: Use the same duration formatting as for the tests (#613) @BeyondEvil
  * fix: Replacing log HTML (#611) @BeyondEvil
  * fix: Incorrect precedence render collapsed (#610) @BeyondEvil
  * chore: Better directory and class structure (#609) @BeyondEvil
  * fix: Deprecate the Cells.pop function (#608) @BeyondEvil
  * fix: Collapsed should support All and none (#605) @BeyondEvil
  * tests: Add tests for stdout and sterr capture (#604) @BeyondEvil
  * fix: Missing logging in report (#603) @BeyondEvil
  * chore: Add code coverage for JS (#600) @BeyondEvil
  * Fix: Table row hook (#599) @BeyondEvil
  * fix: Report fails to render with pytest-xdist (#598) @BeyondEvil
  * fix: Add config to report object (#588) @BeyondEvil
  * update: duration_format renders deprecation warning (#589) @BeyondEvil
  * chore: Add unit test file (#590) @BeyondEvil
  * refactor: stop overwriting pytest data (#597) @BeyondEvil
  * Combined fe and be (#479) @BeyondEvil
  * Revert "Rename master branch to main" (#562) @BeyondEvil
  * Switch to setuptools-scm >= 7.0.0 (#567) @dvzrv
* Wed Aug  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-assertpy-dep.patch to remove assertpy dependency
- Add vendor-npm.patch to vendor npm build requirements
- Update to 4.0.0rc5, compatible with python-pytest-metadata 3.0.0
  (gh#pytest-dev/pytest-html#683)
  - No release notes upstream
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Nov 30 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- Add python-py dependency
- Update to 3.2.0
  * Explicitly add py.xml dependency.
    Thanks to @smartEBL for the PR
  * Implement the visible URL query parameter to control visibility of test
    results on page load. (#399)
    Thanks to @TheCorp for reporting and @gnikonorov for the fix
  * Make the report tab title reflect the report name. (#412)
    Thanks to @gnikonorov for the PR
  * Implement environment_table_redact_list to allow for redaction of
    environment table values. (#233)
    Thanks to @fenchu for reporting and @gnikonorov for the PR
* Mon Jan 18 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 3.1.1
  * Fix issue with reporting of missing CSS files. (#388)
    Thanks to @prakhargurunani for reporting and fixing!
- Changelog for 3.1.0
  * Stop attaching test reruns to final test report entries (#374)
    Thanks to @VladimirPodolyan for reporting and @gnikonorov for
    the fix
  * Allow for report duration formatting (#376)
    Thanks to @brettnolan for reporting and @gnikonorov for the fix
- Changelog for 3.0.0
  * Respect --capture=no, --show-capture=no, and -s pytest flags
    (#171) Thanks to @bigunyak for reporting and @gnikonorov for the
    fix
  * Make the Results table Links column sortable (#242)
    Thanks to @vashirov for reporting and @gnikonorov for the fix
  * Fix issue with missing image or video in extras. (#265 and
    pytest-selenium#237)
    Thanks to @p00j4 and @anothermattbrown for reporting and
    @christiansandberg and @superdodd and @dhalperi for the fix
  * Fix attribute name for compatibility with pytest-xdist 2. (#305)
    Thanks to @Zac-HD for the fix
  * Post process HTML generation to allow teardown to appear in the
    HTML output. (#131)
    Thanks to @iwanb for reporting and @csm10495 for the fix
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.1:
  * Fix issue with funcargs causing failures. (#282)
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
  * Added support for MP4 video format. (#260)
  * Added support for sorting metadata by key. (#245)
  * Added support for rendering reports collapsed (#239)
  * Added extra fixture (#269)
  * Added ability to change report title using hook (#270)
* Tue Mar  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Raise minimal pytest version
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.1:
  * Properly check for presence of CSS file
  * Added support for UTF-8 display
  * Fix initial sort on column
* Fri Sep 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.0:
  * Drop support for python 2.7
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Define LANG in %%check to fix openSUSE/SLE 15 builds
* Mon Aug 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.22.0:
  * Refactor asset naming to be OS safe
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.21.1:
  * Fix issue with assets filenames being too long.
  * Allow opening generated html report in browser (@ssbarnea)
  * Handle when report title is stored as an environment variable (@BeyondEvil)
  * Change assets naming method (@SunInJuly)
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix typo in the ansi2html Requires
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.20.0:
  * Tests running with Pytest 4.0 and Python 3.7
  * Stop filtering out falsy environment values (#175)
  * Removed extraneous space from anchor tag (@chardbury)
  * Always define __version__ even if get_distribution() fails (@nicoddemus)
  * Refactor css config code (@crazymerlyn)
* Thu Nov 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Cleanup with spec-cleaner
- Make sure the tests are really executed
- Remove useless devel dependency
* Fri Nov 16 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.19.0
